$!----------------------------------------------------------$
$! A script to compile bsoft programs on VMS                $
$! Authors: Bernard Heymann, Pam Hill                       $
$! 20000112 - 20050202                                      $
$!                                                          $
$! Requirements:                                            $
$!      Libraries:     TIFF, JPEG, ZLIB, PNG, FFTW          $
$!                                                          $
$!----------------------------------------------------------$
$
$ set noverify
$
$ on error then continue
$ delete [...]^.*.c;*
$
$ on error then exit
$
$! DFLAG = "/debug"
$! DFLAG = P1
$
$! CFLAG = "/float=IEEE_FLOAT /POINTER_SIZE=64 "
$ CFLAG = "/name=(as_is,short)/float=IEEE_FLOAT "
$
$!----------------------------------------------------------$
$! Directories for the package and the binaries             $
$!     CHANGE TO SUIT INSTALLATION                          $
$!----------------------------------------------------------$
$
$ BSOFT = F$DIRECTORY()
$ write sys$output "Bsoft directory: ",BSOFT
$
$ set default [.src]
$ BSRC = F$DIRECTORY()
$ set default [-]
$ write sys$output "Bsoft source: ",BSRC
$
$ BINDIR = F$SEARCH("bin.dir")
$ if BINDIR .eqs. "" then CREATE/DIR [.bin]
$ 
$ set default [.bin]
$ BBIN = F$DIRECTORY()
$ set default [-]
$ write sys$output "Bsoft binaries: ",BBIN
$
$ LIBDIR = F$SEARCH("lib.dir")
$ if LIBDIR .eqs. "" then CREATE/DIR [.lib]
$ 
$ set default [.lib]
$ BLIB = F$DIRECTORY()
$ set default [-]
$ write sys$output "Bsoft libraries: ",BLIB
$
$ set default [.parameters]
$ BPARAM = F$DIRECTORY()
$ set default [-]
$ write sys$output "Bsoft parameters: ",BPARAM
$
$! Path to the executable binaries and parameters        
$ DEFINE BSOFTBIN 'BBIN'
$ DEFINE BPARAM 'BPARAM'
$
$!----------------------------------------------------------$
$! System identification and compiler selection             $
$!     CHANGE TO SUIT INSTALLATION                          $
$!----------------------------------------------------------$
$
$ write sys$output "System: VMS"
$ write sys$output "Compilers: CC CXX"
$ write sys$output "C flags: ", CFLAG
$
$!----------------------------------------------------------$
$! Package subdirectories, path to includes and libraries   $
$!----------------------------------------------------------$
$
$ SUBDIR = "img,mg,mol,model,ps,rwimg,rwmol,rwmodel,rwparam,util"
$ write sys$output "Bsoft source subdirectories: ",SUBDIR
$
$
$ set default [.include]
$ INCLUDES = "("+F$DIRECTORY()+")"
$ set default [-]
$ write sys$output "Bsoft includes: ",INCLUDES
$
$ define lnk$library SYS$SHARE:VAXCRTLT.OLB
$ TIFFLIB = "sys$library:TIFF.OLB/lib"
$ JPEGLIB = "sys$library:LIBJPEG.OLB/lib"
$ ZLIB = "sys$library:LIBZ.OLB/lib"
$ PNGLIB = "sys$library:LIBPNG.OLB/lib"
$ FFTWLIB = "sys$library:LIBFFTW.OLB/lib"
$ BSOFTLIB = BLIB+"LIBBSOFT.OLB/lib"
$
$!----------------------------------------------------------$
$! Compilation and installation                             $
$!----------------------------------------------------------$
$!
$! Compiling the I/O and utility files and
$! Collecting object files for an object library
$!
$ set default 'BSRC
$ num = 0
$ OBJECTS = ""
$ compile = "cxx"
$ loopdir:
$     DIR = F$ELEMENT(num,",",SUBDIR)
$     if (DIR .eqs. "") .or. (DIR .eqs. ",") then goto endloopdir
$     CLEN = f$locate("]",BSRC)
$     DIR = f$extract(0,CLEN,BSRC) + "." + DIR + "]"
$     gosub CompileSource
$     write sys$output "Adding objects from directory:  ", DIR
$     if num .ne. 0 then OBJECTS = OBJECTS + ","
$     OBJECTS = OBJECTS + DIR + "*.obj"
$     purge
$     set default [-]
$     num = num + 1
$     goto loopdir
$ endloopdir:
$
$ write sys$output "Object library directory: ",F$DIRECTORY()
$ write sys$output "Object list: ",OBJECTS
$ OBJLIB = "LIBBSOFT.OLB"
$ gosub CreateLibrary
$
$ set default 'BLIB'
$ purge
$
$! Compiling the main program source files
$ DIR = BSRC
$ compile = "cxx"
$ gosub CompileSource
$
$! Linking the programs
$ set default 'BSRC
$ if P1 .eqs. ""
$ then
$   looplink:
$     OFILE = F$SEARCH("*.OBJ")
$     if OFILE .EQS. "" then goto endlink
$     OFILE = F$EXTRACT(0,F$LOCATE(".OBJ",OFILE),OFILE)
$     write sys$output "Linking: ",OFILE
$     cxxlink 'OFILE', 'BSOFTLIB','TIFFLIB','JPEGLIB','PNGLIB','ZLIB','FFTWLIB' 'DFLAG'
$     goto looplink
$   endlink:
$ else
$     write sys$output "Linking: ",P1
$     cxxlink 'P1', 'BSOFTLIB','TIFFLIB','JPEGLIB','PNGLIB','ZLIB','FFTWLIB' 'DFLAG'
$ endif
$
$! Installing all the binaries
$ write sys$output "Installing programs in ",BBIN
$ purge
$ rename *.exe 'BBIN'
$ set default 'BBIN'
$ purge
$ set security *.exe;* /prot=(s:rwed,o:rwed,g:re,w:re)
$ set default 'BSOFT'
$
$ write sys$output "Set the following in LOGIN.COM:"
$ write sys$output "The path to the executable binaries:"
$ write sys$output "$ DEFINE BSOFTBIN ",BBIN
$ write sys$output "$ DEFINE DCL$PATH BSOFTBIN"
$ write sys$output "The environmental variable:"
$ write sys$output "$ BPARAM == ",BPARAM
$
$ EXIT
$
$!
$! Subroutines
$!
$ CompileSource:
$ set default 'DIR
$ write sys$output "Compiling In Directory:  ",DIR
$ CompileLoop:
$     CFILE = F$SEARCH("*.C",1)
$     if CFILE .EQS. "" then goto EndCompileLoop
$     CLEN = F$LOCATE(".C",CFILE)
$     OFILE = F$EXTRACT(0,CLEN,CFILE)+".OBJ"
$     OFILE = F$SEARCH(OFILE,2)
$     if OFILE .nes. ""
$     then
$	CTIME = F$FILE_ATTRIBUTES(CFILE,"RDT")
$	OTIME = F$FILE_ATTRIBUTES(OFILE,"RDT")
$	if F$CVTIME(OTIME) .gts. F$CVTIME(CTIME) then goto CompileLoop
$     endif
$     write sys$output "Compiling ",CFILE
$     'compile' 'CFILE'/include='INCLUDES' 'CFLAG' 'DFLAG'
$     goto CompileLoop
$ EndCompileLoop:
$ RETURN
$!
$ CreateLibrary:
$ write sys$output "Creating Object library: ",OBJLIB
$ library/create 'OBJLIB' 'OBJECTS
$ purge
$ rename 'OBJLIB' 'BLIB'
$ RETURN
